@@ -943,12 +943,11 @@ g_key_file_to_data (GKeyFile  *key_file,
 
       group = (GKeyFileGroup *) group_node->data;
 
-      /* separate groups by an empty line */
-      if (group_node->next)
-        g_string_append_c (data_string, '\n');
-
       if (group->comment != NULL)
         g_string_append_printf (data_string, "%s\n", group->comment->value);
+      else if (group_node->next) /* separate groups by at least an empty line */
+        g_string_append_c (data_string, '\n');
+
       if (group->name != NULL)
         g_string_append_printf (data_string, "[%s]\n", group->name);
 
